<?php
/**
 * 2007-2015 Leotheme
 *
 * NOTICE OF LICENSE
 *
 * Leo Halloween Bat
 *
 * DISCLAIMER
 *
 *  @author    leotheme <leotheme@gmail.com>
 *  @copyright 2007-2015 Leotheme
 *  @license   http://leotheme.com - prestashop template provider
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

class LeoHalloweencountdown extends Module
{
	public function __construct()
	{
		$this->name = 'leohalloweencountdown';
        $this->tab = 'front_office_features';
        $this->version = '1.0.1';
        $this->author = 'Leotheme';
        $this->need_instance = 0;

        $this->ps_versions_compliancy = [
            'min' => '1.7',
            'max' => _PS_VERSION_,
        ];

        $this->bootstrap = true;
        parent::__construct();

        $current_index = AdminController::$currentIndex;
        $this->base_config_url = $current_index.'&configure='.$this->name.'&token='.Tools::getValue('token');
        $this->displayName = $this->trans('Leo Halloween Countdown');
        $this->description = $this->trans('Leo Halloween Countdown For Prestashop 1.7');
	}

    /**
     * @see Module::install()
     */
	public function install()
    {	
        Configuration::updateValue('HCD_ACTIVE_DESKTOP', 1);
        Configuration::updateValue('HCD_ACTIVE_MOBILE', 1);
        Configuration::updateValue('HCD_ACTIVE_HCD_TEXTBEFORE', 1);
        Configuration::updateValue('HCD_ACTIVE_HCD_TEXTAFTER', 1);
        Configuration::updateValue('HCD_TEXTBEFORE', '');
        Configuration::updateValue('HCD_TEXTAFTER', '');
        return parent::install()
        &&$this->registerHook('displayHome')
        &&$this->registerHook('displayLeoHalloweencountdown');
    }

    /**
     * @see Module::uninstall()
     */
    public function uninstall()
    {
    	Configuration::deleteByName('HCD_ACTIVE_DESKTOP');
        Configuration::deleteByName('HCD_ACTIVE_MOBILE');
        Configuration::deleteByName('HCD_ACTIVE_HCD_TEXTBEFORE');
        Configuration::deleteByName('HCD_ACTIVE_HCD_TEXTAFTER');
        Configuration::deleteByName('HCD_TEXTBEFORE');
        Configuration::deleteByName('HCD_TEXTAFTER');
    	return parent::uninstall();
    }

    /**
    *   List hook
    */
    public function hookDisplayHome()
    {
        return $this->hookDisplayLeoHalloweencountdown();
    }

    public function hookDisplayLeoHalloweencountdown()
    {

        $this->context->controller->addCSS($this->_path.'views/css/halloweencountdown.css');
        $languages = Language::getLanguages(false);
        $mobile_detect = Context::getContext()->isMobile();
        $mobile_class = 'desktop';
        if ($mobile_detect){
            $mobile_class = 'mobile';
        }
       
        $lang_bo = (int)Configuration::get('PS_LANG_DEFAULT');
        $id_lang_fo = $this->context->language->id;

        foreach ($languages as $lang) {
            if($lang['id_lang'] == $id_lang_fo){
                $this->context->smarty->assign(array(
                    'HCD_ACTIVE_DESKTOP' => Configuration::get('HCD_ACTIVE_DESKTOP'),
                    'HCD_ACTIVE_MOBILE' => Configuration::get('HCD_ACTIVE_MOBILE'),
                    'active_textbf' => Configuration::get('HCD_ACTIVE_HCD_TEXTBEFORE'),
                    'active_textat' => Configuration::get('HCD_ACTIVE_HCD_TEXTAFTER'),
                    'active_textbf_link' => Configuration::get('HCD_ACTIVE_HCD_TEXTBEFORE_LINK'),
                    'active_textat_link' =>Configuration::get('HCD_ACTIVE_HCD_TEXTAFTER_LINK'),
                    'urlbf' => Configuration::get('HCD_TEXTBEFORE_LINK'),
                    'urlat' => Configuration::get('HCD_TEXTAFTER_LINK'),

                    'HCD_TEXTBEFORE' => Configuration::get('HCD_TEXTBEFORE_'.$lang['id_lang']),
                    'HCD_TEXTAFTER' => Configuration::get('HCD_TEXTAFTER_'.$lang['id_lang']),
                    'languages' => $languages,
                    
                    'isMobile' => $mobile_class,
                ));
            }
        }
        return $this->display(__FILE__, 'halloweencountdown.tpl');
    }

    public function getContent()
    {
    	$output ='';
    	$errors = array();
        $languages = Language::getLanguages(false);

    	if(Tools::isSubmit('submit'.$this->name)){
            $adt = Tools::getValue('HCD_ACTIVE_DESKTOP');
    		if(!Validate::isBool($adt)){
    			$errors[] = $this->trans('Invalid value for the "active desktop"');
    		}
            $amb = Tools::getValue('HCD_ACTIVE_MOBILE');
    		if(!Validate::isBool($amb)){
    			$errors[] = $this->trans('Invalid value for the "active mobile"');
    		}

            $boolbefore = Tools::getValue('HCD_ACTIVE_HCD_TEXTBEFORE');
            $boolafter = Tools::getValue('HCD_ACTIVE_HCD_TEXTAFTER');
            if(!Validate::isBool($boolbefore) || !Validate::isBool($boolafter)){
                $errors[] = $this->trans('Invalid value for the "active text"');
            }

            $activeHCD_TEXTBEFORELink = Tools::getValue('HCD_ACTIVE_HCD_TEXTBEFORE_LINK');
            $activeHCD_TEXTAFTERLink = Tools::getValue('HCD_ACTIVE_HCD_TEXTAFTER_LINK');
            if(!Validate::isBool($activeHCD_TEXTBEFORELink) || !Validate::isBool($activeHCD_TEXTAFTERLink)){
                $errors[] = $this->trans('Invalid value for the "active mobile"');
            }

            $urlHCD_TEXTBEFORE = Tools::getValue('HCD_TEXTBEFORE_LINK');
            $urlHCD_TEXTAFTER = Tools::getValue('HCD_TEXTAFTER_LINK');
            if(!Validate::isString($urlHCD_TEXTBEFORE) || !Validate::isString($urlHCD_TEXTAFTER)){
                $errors[] = $this->trans('Invalid value for the "text"');
            }
    		if($errors){
    			$this->displayError($this->trans('Invalid Configuration value'));
    		}
    		else{
    			Configuration::updateValue('HCD_ACTIVE_DESKTOP',(bool)$adt);
    			Configuration::updateValue('HCD_ACTIVE_MOBILE',(bool)$amb);
                Configuration::updateValue('HCD_ACTIVE_HCD_TEXTBEFORE',(bool)$boolbefore);
                Configuration::updateValue('HCD_ACTIVE_HCD_TEXTAFTER',(bool)$boolafter);

                Configuration::updateValue('HCD_TEXTBEFORE_LINK',(string)$urlHCD_TEXTBEFORE);
                Configuration::updateValue('HCD_ACTIVE_HCD_TEXTBEFORE_LINK',(bool)$activeHCD_TEXTBEFORELink);
                Configuration::updateValue('HCD_TEXTAFTER_LINK',(string)$urlHCD_TEXTAFTER);
                Configuration::updateValue('HCD_ACTIVE_HCD_TEXTAFTER_LINK',(bool)$activeHCD_TEXTAFTERLink);
                $output = $this->displayConfirmation($this->trans('The settings have been updated.', array(), 'Admin.Notifications.Success'));
    		}
            foreach ($languages as $lang) {
                Configuration::updateValue('HCD_TEXTBEFORE_'.(int)$lang['id_lang'],Tools::getValue('HCD_TEXTBEFORE_'.(int)$lang['id_lang'])); 
                Configuration::updateValue('HCD_TEXTAFTER_'.(int)$lang['id_lang'],Tools::getValue('HCD_TEXTAFTER_'.(int)$lang['id_lang']));      
            }
    	}
    	return $output.$this->renderFormList().$this->linksetposition();
    }

    

    public function renderFormList()
    {
    	$fields_form = array(
    		'form' => array(
    			'legend' => array(
    				'title' => $this->trans('Halloween countdown setting'),
    				'icon' => 'icon-cogs',
    			),
    			'input' => array(
    				array(
	    				'type' => 'switch',
	    				'label' => $this->trans('Active On Desktop'),
	    				'name' => 'HCD_ACTIVE_DESKTOP',
	    				'desc' => $this->trans('Enable if you wish it to be displayed on desktop'),
	    				'values' => array(
	    					array(
	    						'id' => 'active_on',
	    						'value' => 1,
	    						'label' => $this->trans('Enable'),
	    					),
	    					array(
	    						'id' => 'active_off',
	    						'value' => 0,
	    						'label' => $this->trans('Disable'),
	    					),
	    				),
	    				'default' => 1,
	    			),	
    				array(
	    				'type' => 'switch',
	    				'label' => $this->trans('Active On Mobile'),
	    				'name' => 'HCD_ACTIVE_MOBILE',
	    				'desc' => $this->trans('Enable if you wish it to be displayed on mobile'),
	    				'values' => array(
	    					array(
	    						'id' => 'active_on',
	    						'value' => 1,
	    						'label' => $this->trans('Enable'),
	    					),
	    					array(
	    						'id' => 'active_off',
	    						'value' => 0,
	    						'label' => $this->trans('Disable'),
	    					),
	    				),
    				),
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Active text before the countdown time'),
                        'name' => 'HCD_ACTIVE_HCD_TEXTBEFORE',
                        'desc' => $this->trans('Enable if you wish it to be displayed.'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->trans('Text before the countdown time'),
                        'name' => 'HCD_TEXTBEFORE',
                        'desc' => $this->trans('The text you want to display before the countdown time'),
                        'form_group_class' => 'HCD_TEXTBEFORE',
                        'lang' =>true,
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Add links to the above text'),
                        'name' => 'HCD_ACTIVE_HCD_TEXTBEFORE_LINK',
                        'desc' => $this->trans('Enable if you wish it to work.'),
                        'form_group_class' => 'HCD_TEXTBEFORE',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->trans('URL'),
                        'name' => 'HCD_TEXTBEFORE_LINK',
                        'desc' => $this->trans('The link you want to transfer to'),
                        'form_group_class' => 'HCD_TEXTBEFORE urlHCD_TEXTBEFORE',
                    ),

                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Active text after the countdown time'),
                        'name' => 'HCD_ACTIVE_HCD_TEXTAFTER',
                        'desc' => $this->trans('Enable if you wish it to be displayed.'),
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->trans('Text after the countdown time'),
                        'name' => 'HCD_TEXTAFTER',
                        'desc' => $this->trans('The text you want to display after the countdown time'),
                        'form_group_class' => 'HCD_TEXTAFTER',
                        'lang' =>true,
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Add links to text below'),
                        'name' => 'HCD_ACTIVE_HCD_TEXTAFTER_LINK',
                        'desc' => $this->trans('Enable if you wish it to work.'),
                        'form_group_class' => 'HCD_TEXTAFTER',
                        'values' => array(
                            array(
                                'id' => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable'),
                            ),
                            array(
                                'id' => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable'),
                            ),
                        ),
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->trans('URL'),
                        'name' => 'HCD_TEXTAFTER_LINK',
                        'desc' => $this->trans('The link you want to transfer to'),
                        'form_group_class' => 'HCD_TEXTAFTER urlHCD_TEXTAFTER',
                    ),
    			),
    			'submit' => array(
                    'title' => $this->trans('Save'),
                    'class' => 'btn btn-default pull-right'
                ),
    		),
    	);

    	$lang = (int)Configuration::get('PS_LANG_DEFAULT');

        $helper = new HelperForm();
        $helper->default_form_language = $lang;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->module = $this;
	    $helper->name_controller = $this->name;
	    $helper->token = Tools::getAdminTokenLite('AdminModules');
	    $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
	    $helper->title = $this->displayName;
	    $helper->submit_action = 'submit'.$this->name;
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );
        $helper->toolbar_btn = [
	        'save' => [
	            'desc' => $this->l('Save'),
	            'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
	            '&token='.Tools::getAdminTokenLite('AdminModules'),
	        ],
	        'back' => [
	            'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
	            'desc' => $this->l('Back to list')
	        ]
    	];
    	$helper->fields_value['leohalloweencountdown'] = Configuration::get('leohalloweencountdown');
        return $helper->generateForm(array($fields_form));
    }

    public function getConfigFieldsValues()
    {   
        $languages = Language::getLanguages(false);
        $fields_form['HCD_ACTIVE_DESKTOP'] = Tools::getValue('HCD_ACTIVE_DESKTOP', (bool)Configuration::get('HCD_ACTIVE_DESKTOP'));
        $fields_form['HCD_ACTIVE_MOBILE'] = Tools::getValue('HCD_ACTIVE_MOBILE', (bool)Configuration::get('HCD_ACTIVE_MOBILE'));
        $fields_form['HCD_ACTIVE_HCD_TEXTBEFORE'] = Tools::getValue('HCD_ACTIVE_HCD_TEXTBEFORE', (bool)Configuration::get('HCD_ACTIVE_HCD_TEXTBEFORE'));
        $fields_form['HCD_ACTIVE_HCD_TEXTAFTER'] = Tools::getValue('HCD_ACTIVE_HCD_TEXTAFTER', (bool)Configuration::get('HCD_ACTIVE_HCD_TEXTAFTER'));
        $fields_form['HCD_ACTIVE_HCD_TEXTBEFORE_LINK'] = Tools::getValue('HCD_ACTIVE_HCD_TEXTBEFORE_LINK', (bool)Configuration::get('HCD_ACTIVE_HCD_TEXTBEFORE_LINK'));
        $fields_form['HCD_TEXTBEFORE_LINK'] = Tools::getValue('HCD_TEXTBEFORE_LINK', (bool)Configuration::get('HCD_TEXTBEFORE_LINK'));
        $fields_form['HCD_ACTIVE_HCD_TEXTAFTER_LINK'] = Tools::getValue('HCD_ACTIVE_HCD_TEXTAFTER_LINK', (bool)Configuration::get('HCD_ACTIVE_HCD_TEXTAFTER_LINK'));
        $fields_form['HCD_TEXTAFTER_LINK'] = Tools::getValue('HCD_TEXTAFTER_LINK', (bool)Configuration::get('HCD_TEXTAFTER_LINK'));
    	
        foreach ($languages as $lang) {
            $fields_form['HCD_TEXTBEFORE'][$lang['id_lang']] = Tools::getValue('HCD_TEXTBEFORE_'.(int)$lang['id_lang'],(string)Configuration::get('HCD_TEXTBEFORE_'.(int)$lang['id_lang']));
            $fields_form['HCD_TEXTAFTER'][$lang['id_lang']] = Tools::getValue('HCD_TEXTAFTER_'.(int)$lang['id_lang'],(string)Configuration::get('HCD_TEXTAFTER_'.(int)$lang['id_lang']));
            
        }
        
        return $fields_form;
    }
    /**
    *   Link change position
    */
    public function linksetposition()
    {   
        $this->context->controller->addJS($this->_path.'views/js/admin/script.js');
        $id_module = $this->id;
        $id_hook = Hook::getIdByName('displayHome');

        $c = new Cookie('psAdmin');
        $id_employee = (int)$c->__get('id_employee');
        $token = Tools::getAdminToken('AdminModulesPositions'.intval(Tab::getIdFromClassName('AdminModulesPositions')).intval($id_employee));
        $url= 'index.php?controller=AdminModulesPositions&id_module='.$id_module.'&id_hook='.$id_hook.'&editGraft=1&token='.$token;
        
        $this->context->smarty->assign(array(
            'linksetposition' => $url,
            'token' => $token,
        ));
        return $this->display(__FILE__, 'views/templates/admin/linksetposition/linksetposition.tpl');
    }
}